@@ -28,7 +28,7 @@ def handle_client(conn, addr):
     x = random.choice(posiible_x_positions)
     z = -3 if team == 'wolf' else 3
     dir = 4.754 if team == 'wolf' else 1.654
-    conn.send(str({'Everything': everything,  'RedFlagPos': redFlagPos, 'BlueFlagPos': blueFlagPos, 'MyInfo': {'team': team, 'x': x, 'z': z, 'dir': dir, 'id': str(addr)}}).encode('utf-8'))
+    conn.send((str({'Everything': everything,  'RedFlagPos': redFlagPos, 'BlueFlagPos': blueFlagPos, 'MyInfo': {'team': team, 'x': x, 'z': z, 'dir': dir, 'id': str(addr)}})+'A@^!').encode('utf-8'))
     everything[str(addr)] = {'pos': [x, 0, z], 'dir': dir, 'team': team, 'touching': False, 'carrying': None, 'prisoner': False}
     notify()
     notifing_list.append(conn)
@@ -73,7 +73,7 @@ def handle_client(conn, addr):
 
 def notify():
     for connection in notifing_list:
-        connection.send(str(everything).encode('utf-8'))
+        connection.send((str(everything)+'A@^!').encode('utf-8'))
 
 redFlagPos = random.choice([[4, 0, 58], [88, 0, 58]])
 blueFlagPos = random.choice([[4, 0, -58], [88, 0, -58]])
