@@ -12,7 +12,7 @@ from threading import Thread as T
 
 BUILD()
 
-Ip = socket.gethostbyname('Anthony')
+Ip = '73.103.247.204'
 Port = 4544
 
 ADDR = (Ip, Port)
@@ -319,6 +319,8 @@ def process_message(dt):
         if person not in message:#Some one left
             scene.unwrapped.entities.remove(people[person])
             del people[person]
+            try: list_of_players_on_my_team.remove(person)
+            except ValueError: list_of_players_on_their_team.remove(person)
             break
 
 @scene.unwrapped.window.event
