@@ -2,9 +2,7 @@ import os
 
 
 def get_subdir_path(sub_dir):
-    # Get the directory this module is located in
-    abs_path_module = os.path.realpath(__file__)
-    module_dir, _ = os.path.split(abs_path_module)
+    module_dir, _ = os.path.split(__file__)
 
     dir_path = os.path.join(module_dir, sub_dir)
 
